/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudsearchv2.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * Container for the parameters to the
 * <code><a>UpdateServiceAccessPolicies</a></code> operation. Specifies the name
 * of the domain you want to update and the access rules you want to configure.
 * </p>
 */
public class UpdateServiceAccessPoliciesRequest extends AmazonWebServiceRequest
        implements Serializable, Cloneable {

    private String domainName;
    /**
     * <p>
     * The access rules you want to configure. These rules replace any existing
     * rules.
     * </p>
     */
    private String accessPolicies;

    /**
     * @param domainName
     */

    public void setDomainName(String domainName) {
        this.domainName = domainName;
    }

    /**
     * @return
     */

    public String getDomainName() {
        return this.domainName;
    }

    /**
     * @param domainName
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public UpdateServiceAccessPoliciesRequest withDomainName(String domainName) {
        setDomainName(domainName);
        return this;
    }

    /**
     * <p>
     * The access rules you want to configure. These rules replace any existing
     * rules.
     * </p>
     * 
     * @param accessPolicies
     *        The access rules you want to configure. These rules replace any
     *        existing rules.
     */

    public void setAccessPolicies(String accessPolicies) {
        this.accessPolicies = accessPolicies;
    }

    /**
     * <p>
     * The access rules you want to configure. These rules replace any existing
     * rules.
     * </p>
     * 
     * @return The access rules you want to configure. These rules replace any
     *         existing rules.
     */

    public String getAccessPolicies() {
        return this.accessPolicies;
    }

    /**
     * <p>
     * The access rules you want to configure. These rules replace any existing
     * rules.
     * </p>
     * 
     * @param accessPolicies
     *        The access rules you want to configure. These rules replace any
     *        existing rules.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public UpdateServiceAccessPoliciesRequest withAccessPolicies(
            String accessPolicies) {
        setAccessPolicies(accessPolicies);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getDomainName() != null)
            sb.append("DomainName: " + getDomainName() + ",");
        if (getAccessPolicies() != null)
            sb.append("AccessPolicies: " + getAccessPolicies());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof UpdateServiceAccessPoliciesRequest == false)
            return false;
        UpdateServiceAccessPoliciesRequest other = (UpdateServiceAccessPoliciesRequest) obj;
        if (other.getDomainName() == null ^ this.getDomainName() == null)
            return false;
        if (other.getDomainName() != null
                && other.getDomainName().equals(this.getDomainName()) == false)
            return false;
        if (other.getAccessPolicies() == null
                ^ this.getAccessPolicies() == null)
            return false;
        if (other.getAccessPolicies() != null
                && other.getAccessPolicies().equals(this.getAccessPolicies()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getDomainName() == null) ? 0 : getDomainName().hashCode());
        hashCode = prime
                * hashCode
                + ((getAccessPolicies() == null) ? 0 : getAccessPolicies()
                        .hashCode());
        return hashCode;
    }

    @Override
    public UpdateServiceAccessPoliciesRequest clone() {
        return (UpdateServiceAccessPoliciesRequest) super.clone();
    }
}