/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.glacier.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * Provides options for initiating an Amazon Glacier job.
 * </p>
 */
public class InitiateJobRequest extends AmazonWebServiceRequest implements
        Serializable, Cloneable {

    /**
     * <p>
     * The <code>AccountId</code> value is the AWS account ID of the account
     * that owns the vault. You can either specify an AWS account ID or
     * optionally a single apos<code>-</code>apos (hyphen), in which case Amazon
     * Glacier uses the AWS account ID associated with the credentials used to
     * sign the request. If you use an account ID, do not include any hyphens
     * (apos-apos) in the ID.
     * </p>
     */
    private String accountId;
    /**
     * <p>
     * The name of the vault.
     * </p>
     */
    private String vaultName;
    /**
     * <p>
     * Provides options for specifying job information.
     * </p>
     */
    private JobParameters jobParameters;

    /**
     * Default constructor for InitiateJobRequest object. Callers should use the
     * setter or fluent setter (with...) methods to initialize the object after
     * creating it.
     */
    public InitiateJobRequest() {
    }

    /**
     * Constructs a new InitiateJobRequest object. Callers should use the setter
     * or fluent setter (with...) methods to initialize any additional object
     * members.
     * 
     * @param vaultName
     *        The name of the vault.
     * @param jobParameters
     *        Provides options for specifying job information.
     */
    public InitiateJobRequest(String vaultName, JobParameters jobParameters) {
        setVaultName(vaultName);
        setJobParameters(jobParameters);
    }

    /**
     * Constructs a new InitiateJobRequest object. Callers should use the setter
     * or fluent setter (with...) methods to initialize any additional object
     * members.
     * 
     * @param accountId
     *        The <code>AccountId</code> value is the AWS account ID of the
     *        account that owns the vault. You can either specify an AWS account
     *        ID or optionally a single apos<code>-</code>apos (hyphen), in
     *        which case Amazon Glacier uses the AWS account ID associated with
     *        the credentials used to sign the request. If you use an account
     *        ID, do not include any hyphens (apos-apos) in the ID.
     * @param vaultName
     *        The name of the vault.
     * @param jobParameters
     *        Provides options for specifying job information.
     */
    public InitiateJobRequest(String accountId, String vaultName,
            JobParameters jobParameters) {
        setAccountId(accountId);
        setVaultName(vaultName);
        setJobParameters(jobParameters);
    }

    /**
     * <p>
     * The <code>AccountId</code> value is the AWS account ID of the account
     * that owns the vault. You can either specify an AWS account ID or
     * optionally a single apos<code>-</code>apos (hyphen), in which case Amazon
     * Glacier uses the AWS account ID associated with the credentials used to
     * sign the request. If you use an account ID, do not include any hyphens
     * (apos-apos) in the ID.
     * </p>
     * 
     * @param accountId
     *        The <code>AccountId</code> value is the AWS account ID of the
     *        account that owns the vault. You can either specify an AWS account
     *        ID or optionally a single apos<code>-</code>apos (hyphen), in
     *        which case Amazon Glacier uses the AWS account ID associated with
     *        the credentials used to sign the request. If you use an account
     *        ID, do not include any hyphens (apos-apos) in the ID.
     */

    public void setAccountId(String accountId) {
        this.accountId = accountId;
    }

    /**
     * <p>
     * The <code>AccountId</code> value is the AWS account ID of the account
     * that owns the vault. You can either specify an AWS account ID or
     * optionally a single apos<code>-</code>apos (hyphen), in which case Amazon
     * Glacier uses the AWS account ID associated with the credentials used to
     * sign the request. If you use an account ID, do not include any hyphens
     * (apos-apos) in the ID.
     * </p>
     * 
     * @return The <code>AccountId</code> value is the AWS account ID of the
     *         account that owns the vault. You can either specify an AWS
     *         account ID or optionally a single apos<code>-</code>apos
     *         (hyphen), in which case Amazon Glacier uses the AWS account ID
     *         associated with the credentials used to sign the request. If you
     *         use an account ID, do not include any hyphens (apos-apos) in the
     *         ID.
     */

    public String getAccountId() {
        return this.accountId;
    }

    /**
     * <p>
     * The <code>AccountId</code> value is the AWS account ID of the account
     * that owns the vault. You can either specify an AWS account ID or
     * optionally a single apos<code>-</code>apos (hyphen), in which case Amazon
     * Glacier uses the AWS account ID associated with the credentials used to
     * sign the request. If you use an account ID, do not include any hyphens
     * (apos-apos) in the ID.
     * </p>
     * 
     * @param accountId
     *        The <code>AccountId</code> value is the AWS account ID of the
     *        account that owns the vault. You can either specify an AWS account
     *        ID or optionally a single apos<code>-</code>apos (hyphen), in
     *        which case Amazon Glacier uses the AWS account ID associated with
     *        the credentials used to sign the request. If you use an account
     *        ID, do not include any hyphens (apos-apos) in the ID.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public InitiateJobRequest withAccountId(String accountId) {
        setAccountId(accountId);
        return this;
    }

    /**
     * <p>
     * The name of the vault.
     * </p>
     * 
     * @param vaultName
     *        The name of the vault.
     */

    public void setVaultName(String vaultName) {
        this.vaultName = vaultName;
    }

    /**
     * <p>
     * The name of the vault.
     * </p>
     * 
     * @return The name of the vault.
     */

    public String getVaultName() {
        return this.vaultName;
    }

    /**
     * <p>
     * The name of the vault.
     * </p>
     * 
     * @param vaultName
     *        The name of the vault.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public InitiateJobRequest withVaultName(String vaultName) {
        setVaultName(vaultName);
        return this;
    }

    /**
     * <p>
     * Provides options for specifying job information.
     * </p>
     * 
     * @param jobParameters
     *        Provides options for specifying job information.
     */

    public void setJobParameters(JobParameters jobParameters) {
        this.jobParameters = jobParameters;
    }

    /**
     * <p>
     * Provides options for specifying job information.
     * </p>
     * 
     * @return Provides options for specifying job information.
     */

    public JobParameters getJobParameters() {
        return this.jobParameters;
    }

    /**
     * <p>
     * Provides options for specifying job information.
     * </p>
     * 
     * @param jobParameters
     *        Provides options for specifying job information.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public InitiateJobRequest withJobParameters(JobParameters jobParameters) {
        setJobParameters(jobParameters);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getAccountId() != null)
            sb.append("AccountId: " + getAccountId() + ",");
        if (getVaultName() != null)
            sb.append("VaultName: " + getVaultName() + ",");
        if (getJobParameters() != null)
            sb.append("JobParameters: " + getJobParameters());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof InitiateJobRequest == false)
            return false;
        InitiateJobRequest other = (InitiateJobRequest) obj;
        if (other.getAccountId() == null ^ this.getAccountId() == null)
            return false;
        if (other.getAccountId() != null
                && other.getAccountId().equals(this.getAccountId()) == false)
            return false;
        if (other.getVaultName() == null ^ this.getVaultName() == null)
            return false;
        if (other.getVaultName() != null
                && other.getVaultName().equals(this.getVaultName()) == false)
            return false;
        if (other.getJobParameters() == null ^ this.getJobParameters() == null)
            return false;
        if (other.getJobParameters() != null
                && other.getJobParameters().equals(this.getJobParameters()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getAccountId() == null) ? 0 : getAccountId().hashCode());
        hashCode = prime * hashCode
                + ((getVaultName() == null) ? 0 : getVaultName().hashCode());
        hashCode = prime
                * hashCode
                + ((getJobParameters() == null) ? 0 : getJobParameters()
                        .hashCode());
        return hashCode;
    }

    @Override
    public InitiateJobRequest clone() {
        return (InitiateJobRequest) super.clone();
    }
}